<?php

namespace Suggestion\Suggestions\Policies;

use Litepie\User\Contracts\UserPolicy;
use Suggestion\Suggestions\Models\Suggestions;

class SuggestionsPolicy
{

    /**
     * Determine if the given user can view the suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function view(UserPolicy $user, Suggestions $suggestions)
    {
        if ($user->canDo('suggestions.suggestions.view') && $user->isAdmin()) {
            return true;
        }

        return $suggestions->user_id == user_id() && $suggestions->user_type == user_type();
    }

    /**
     * Determine if the given user can create a suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('suggestions.suggestions.create');
    }

    /**
     * Determine if the given user can update the given suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function update(UserPolicy $user, Suggestions $suggestions)
    {
        if ($user->canDo('suggestions.suggestions.edit') && $user->isAdmin()) {
            return true;
        }

        return $suggestions->user_id == user_id() && $suggestions->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Suggestions $suggestions)
    {
        return $suggestions->user_id == user_id() && $suggestions->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Suggestions $suggestions)
    {
        if ($user->canDo('suggestions.suggestions.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given suggestions.
     *
     * @param UserPolicy $user
     * @param Suggestions $suggestions
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Suggestions $suggestions)
    {
        if ($user->canDo('suggestions.suggestions.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
