<?php

namespace Suggestion\Suggestions\Providers;

use Illuminate\Support\ServiceProvider;

class SuggestionsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'suggestions');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'suggestions');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSuggestions();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSuggestions()
    {
        $this->app->bind('suggestions', function($app) {
            return new Suggestions($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Suggestions', 'Lavalite\Suggestions\Facades\Suggestions');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('suggestion.suggestions', function ($app) {
            return $this->app->make('Suggestion\Suggestions\Suggestions');
        });

                // Bind Suggestions to repository
        $this->app->bind(
            'Suggestion\Suggestions\Interfaces\SuggestionsRepositoryInterface',
            \Suggestion\Suggestions\Repositories\Eloquent\SuggestionsRepository::class
        );

        $this->app->register(\Suggestion\Suggestions\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Suggestion\Suggestions\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and suggestions's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'suggestion.suggestions'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSuggestions::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['suggestion.suggestions'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('suggestion/suggestions.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/suggestions')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/suggestions')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
